### TODO

In addition to the todo in the code

### Asap
* **[DOC]** give more details as to the pendent drop method and the methods used here
* **[LIB]** add more user_friendly methods to Parameters (`set_capillary_length`, `set_tip_radius`, etc...)

### Bonus
* **[GUI]** green isoline for main contour, yellow for other lines
